//
//  NewFlowerViewController.m
//  NewFlower
//
//  Created by kunii on 09/12/23.
//  Copyright __MyCompanyName__ 2009. All rights reserved.
//

#import "NewFlowerViewController.h"
#import "ImageKit.h"

@implementation NewFlowerViewController
@synthesize newflowerDelegate;

-(id)init {
    if (self = [super init]) {
		self.title = @"投稿";
		newImage = nil;
	}
    return self;
}
/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil]) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/

/*
	画像を選択（撮影）しHTTPサーバに送信する。
*/
-(IBAction)sendImage
{
	if ([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera] == YES) {	//　カメラ機能が使えるか？
		UIActionSheet* action = [[UIActionSheet alloc] initWithTitle:@"画像を選択" 
			delegate:self cancelButtonTitle:@"キャンセル" 
			destructiveButtonTitle:nil 
			otherButtonTitles:@"写真を撮る",@"既存の項目を選択",nil] ;
		if (action) {
			action.actionSheetStyle = UIBarStyleBlackTranslucent;	// スタイル設定
			[action showInView:self.view];				//　方法選択のアクションシートを開く
			[action release];
		}
	} else {
		//	カメラがないので無条件にアルバムから選択させる。
		[self actionSheet:nil clickedButtonAtIndex:1];
	}
}

/*
	カメラ撮影、アルバムから選択
*/
- (void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex
{
	if (buttonIndex == 2) {									// キャンセルボタン
		return;
	}
	int types[] = {
		UIImagePickerControllerSourceTypeCamera,			//	カメラ撮影
		UIImagePickerControllerSourceTypePhotoLibrary		//	アルバムから選択
	};
	UIImagePickerController* picker = [[UIImagePickerController alloc] init];
	if (picker) {
		picker.allowsImageEditing = YES;		//　画像のトリミングを許可
		picker.sourceType = types[buttonIndex];	//　カメラ撮影かアルバムから選択を指定
		picker.delegate = self;
		[self presentModalViewController:picker animated:YES];
		[picker release];
	}
}

- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingImage:(UIImage *)image editingInfo:(NSDictionary *)editingInfo {
	
	[newImage release];
	newImage = [image retain];	//	登録時に渡すために保持する。

	//	自分が作りたい画像の大きさを決めて描画領域を作る。
	CGRect bounds = [imageButton contentRectForBounds:imageButton.bounds];

	double wide = bounds.size.height * 2 / 3;	//	ボタンの内容部高さの 2/3 を最大とする。
	CGSize size = image.size;
	CGFloat ratio = 0;
	if (size.width > size.height) {		//	横長なので、横幅で比率計算。
		ratio = wide / size.width;
	} else {							//	縦長。
		ratio = wide / size.height;
	}
	//	計算した描画領域を指定して描画準備。
	UIImage* scaledImage = createScaledImage(image, ratio * size.width, ratio * size.height);
	double refHeight = bounds.size.height * 1 / 3;
	UIImage* reflectImage = createReflectedImage(refHeight, scaledImage);
	UIGraphicsBeginImageContext(bounds.size);
	//	UIGraphicsGetImageFromCurrentImageContextが呼ばれるまで
	//	描画はすべて新しい描画領域が対象となる。
	[[UIColor blackColor] setFill];
	UIRectFill(bounds);
	
	CGRect rect = bounds;
	rect.size = scaledImage.size;
	rect.origin.x = (bounds.size.width - scaledImage.size.width) / 2;
	[scaledImage drawInRect:rect];				//	イメージ描画。
	rect.origin.y += rect.size.height + 1;
	rect.size.height = refHeight;
	[reflectImage drawInRect:rect];				//	イメージ描画。
	//	新しい描画領域からUIImageを作成。
	image = UIGraphicsGetImageFromCurrentImageContext();	
	UIGraphicsEndImageContext();			//	解除。
	//	スケーリングされたUIImageを設定。
	[imageButton setImage:image forState:UIControlStateNormal];
	//	説明文は消す。
	[imageButton setTitle:nil forState:UIControlStateNormal];
	
	self.navigationItem.rightBarButtonItem 
			= [[[UIBarButtonItem alloc] initWithTitle:@"投稿する"
			style:UIBarButtonItemStylePlain target:self 
			action:@selector(endModal)] autorelease];
//	[imageButton setImage:image forState:UIControlStateNormal];
//	[imageButton setBackgroundImage:image forState:UIControlStateNormal];
	[self dismissModalViewControllerAnimated:YES];	//　画像ピッカーを閉じる
}

- (void)imagePickerControllerDidCancel:(UIImagePickerController *)picker
{
	[self dismissModalViewControllerAnimated:YES];	//　画像ピッカーを閉じる
}

- (void)resetImage {
	[imageButton setImage:nil forState:UIControlStateNormal];
	[newImage release];
	newImage = nil;
	self.navigationItem.rightBarButtonItem = nil;
}

//	キャンセルなのでnewFlower:nil comment:nilとする。
- (void)cancelModal {
	if ([newflowerDelegate respondsToSelector:@selector(newFlower:comment:)]) {
		[newflowerDelegate newFlower:nil comment:nil];
	}
	[self resetImage];
}

//	投稿なので、newImageを委譲先に渡す。
- (void)endModal {
	if ([newflowerDelegate respondsToSelector:@selector(newFlower:comment:)]) {
		[newflowerDelegate newFlower:newImage comment:commentView.text];
	}
	[self resetImage];
}

// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
	[[NSNotificationCenter defaultCenter] addObserver:self
		selector:@selector(keyboardWasShown:)
		name:UIKeyboardDidShowNotification object:nil];
	[[NSNotificationCenter defaultCenter]addObserver:self
		selector:@selector(keyboardWasHidden:)
		name:UIKeyboardDidHideNotification object:nil];

	self.navigationItem.leftBarButtonItem 
			= [[[UIBarButtonItem alloc] initWithTitle:@"キャンセル"
			style:UIBarButtonItemStylePlain target:self 
			action:@selector(cancelModal)] autorelease];
}



/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	[super viewDidUnload];
	[[NSNotificationCenter defaultCenter] removeObserver:self
		name:UIKeyboardDidShowNotification object:nil];
	[[NSNotificationCenter defaultCenter] removeObserver:self
		name:UIKeyboardDidHideNotification object:nil];
}


- (void)dealloc {
	[newImage release];
    [super dealloc];
}


- (void)keyboardWasShown:(NSNotification*)aNotification { 
	NSDictionary* info = [aNotification userInfo];
	//	キーボードのサイズを取得する
	NSValue* aValue = [info objectForKey:UIKeyboardBoundsUserInfoKey];
	double bottomBounds = self.view.bounds.size.height - [aValue CGRectValue].size.height;
	//	commentViewの親ビュー上の座標を取り出し保存。
	savedFrame = [commentView frame];
	//	最上部に移動。
	CGRect viewFrame = savedFrame;
	viewFrame.origin.y = 8;
	//	移動した矩形の下部がキーボードに隠されないよう調整。
	if ((viewFrame.origin.y + viewFrame.size.height) > bottomBounds)
		viewFrame.size.height = bottomBounds - viewFrame.origin.y;
	//	新しい矩形を設定。
	commentView.frame = viewFrame;
	//	テキスト入力完了通知用ボタンを用意。
	UIBarButtonItem *doneButton = 
		[[UIBarButtonItem alloc] initWithTitle:@"入力完了" 
		style:UIBarButtonItemStyleDone target:self action:@selector(commentDone:)];
	self.navigationItem.rightBarButtonItem = doneButton;
	[doneButton release];
 }

- (void)keyboardWasHidden:(NSNotification*)aNotification { 
	//	commentViewの親ビュー上の座標を保存した矩形に戻す。
	commentView.frame = savedFrame;
} 

-(void)commentDone:(id)sender {
	[commentView resignFirstResponder];
	self.navigationItem.rightBarButtonItem = nil;
}

@end
